@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 from tkinter import W
-import get
+from actions import get
 
 import rich_click as click
 from click_shell import shell
